<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="${comment}" prop="harmpinyin">
                <el-input v-model="queryParams.harmpinyin" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="${comment}" prop="sort">
                <el-input v-model="queryParams.sort" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="${comment}" prop="externalcode">
                <el-input v-model="queryParams.externalcode" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="${comment}" prop="harmcode">
                <el-input v-model="queryParams.harmcode" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="${comment}" prop="protection">
                <el-input v-model="queryParams.protection" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
                    v-hasPermi="['hosp:harmType:add']">新增
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
                    v-hasPermi="['hosp:harmType:edit']">修改
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
                    v-hasPermi="['hosp:harmType:remove']">删除
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
                    v-hasPermi="['hosp:harmType:export']">导出
                </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="harmTypeList" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="${comment}" align="center" prop="aid" />
            <el-table-column label="${comment}" align="center" prop="harmpinyin" />
            <el-table-column label="${comment}" align="center" prop="harmtype" />
            <el-table-column label="${comment}" align="center" prop="sort" />
            <el-table-column label="${comment}" align="center" prop="harminfo" />
            <el-table-column label="${comment}" align="center" prop="externalcode" />
            <el-table-column label="${comment}" align="center" prop="harmcode" />
            <el-table-column label="${comment}" align="center" prop="type" />
            <el-table-column label="${comment}" align="center" prop="protection" />
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                        v-hasPermi="['hosp:harmType:edit']">修改
                    </el-button>
                    <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                        v-hasPermi="['hosp:harmType:remove']">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>

        <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
            @pagination="getList" />

        <!-- 添加或修改职业病对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="${comment}" prop="harmpinyin">
                    <el-input v-model="form.harmpinyin" placeholder="请输入${comment}" />
                </el-form-item>
                <el-form-item label="${comment}" prop="sort">
                    <el-input v-model="form.sort" placeholder="请输入${comment}" />
                </el-form-item>
                <el-form-item label="${comment}" prop="harminfo">
                    <el-input v-model="form.harminfo" type="textarea" placeholder="请输入内容" />
                </el-form-item>
                <el-form-item label="${comment}" prop="externalcode">
                    <el-input v-model="form.externalcode" placeholder="请输入${comment}" />
                </el-form-item>
                <el-form-item label="${comment}" prop="harmcode">
                    <el-input v-model="form.harmcode" placeholder="请输入${comment}" />
                </el-form-item>
                <el-form-item label="${comment}" prop="protection">
                    <el-input v-model="form.protection" placeholder="请输入${comment}" />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listHarmType,
    getHarmType,
    delHarmType,
    addHarmType,
    updateHarmType
} from "@/api/hosp/harmType";

export default {
    name: "HarmType",
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 职业病表格数据
            harmTypeList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                harmpinyin: null,
                harmtype: null,
                sort: null,
                harminfo: null,
                externalcode: null,
                harmcode: null,
                type: null,
                protection: null
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
            }
        };
    },
    created() {
        this.getList();
    },
    methods: {
        /** 查询职业病列表 */
        getList() {
            this.loading = true;
            listHarmType(this.queryParams).then(response => {
                this.harmTypeList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                aid: null,
                harmpinyin: null,
                harmtype: null,
                sort: null,
                harminfo: null,
                externalcode: null,
                harmcode: null,
                type: null,
                protection: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.aid)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加职业病";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const aid = row.aid || this.ids
            getHarmType(aid).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改职业病";
            });
        },
        /** 提交按钮 */
        submitForm() {

        },
        /** 删除按钮操作 */
        handleDelete(row) {


        },


        SelectionChange(selection) { },



        /** 导出按钮操作 */
        handleExport() {

        }
    }
}
    ;
</script>
